@@ -25,7 +25,7 @@ end
 class OggInfoError < StandardError ; end
 
 class OggInfo
-  VERSION = "0.6.12"
+  VERSION = "0.7.2"
   extend Forwardable
   include Ogg
   
@@ -78,6 +78,56 @@ class OggInfo
   def bitrate
     @bitrate ||= (@filesize * 8).to_f / length()
   end
+
+  # set a picture (.jpg or .png) on the ogg file
+  def picture=(filepath)
+    ext = File.extname(filepath)
+    mime_type = {
+      ".jpg" => "image/jpeg",
+      ".png" => "image/png"
+    }[ext]
+    description = "folder#{ext}"
+    raw_string = 
+      [3,               # picture type
+       mime_type.size,
+       mime_type,
+       description.size,
+       description,
+       0,               # width
+       0,               # height
+       0,               # color depth
+       0,               # number of colors used
+       File.size(filepath),
+       File.binread(filepath)
+      ].pack("NNa*Na*NNNNNa*")
+       
+    @tag["METADATA_BLOCK_PICTURE"] = [raw_string].pack("m*").strip
+  end
+  
+  # get the picture as an array of [extension, file_content]
+  # or nil if not existent
+  def picture
+    extensions = {
+      "image/jpeg" => ".jpg",
+      "image/png" => ".png" 
+    }
+
+    if content = tag["metadata_block_picture"]
+      _, #type, # picture type
+      _, # mime_type size
+      mime_type, 
+      _, # description size
+      _, # description, 
+      _, # width
+      _, # height
+      _, # color depth
+      _, # number of color used
+      _, #file_content_size, 
+      file_content = content.unpack("m*").first.unpack("NNa10Na10NNNNNa*")
+      return [extensions[mime_type], file_content]
+    end
+    nil
+  end
   
   # "block version" of ::new()
   def self.open(*args)
